==> vue-user-head-group-2.8.0.tgz: package/lib/mobile-first.js <==
import { renderless, api } from "@dftvue2-opentiny/vue-renderless/user-head-group/vue";
import { defineComponent, props, setup as _setup } from "@dftvue2-opentiny/vue-common";
import UserHead from "@dftvue2-opentiny/vue-user-head";
function normalizeComponent(scriptExports, render, staticRenderFns, functionalTemplate, injectStyles, scopeId, moduleIdentifier, shadowMode) {
  var options = typeof scriptExports === "function" ? scriptExports.options : scriptExports;
  if (render) {
    options.render = render;
    options.staticRenderFns = staticRenderFns;
    options._compiled = true;
  }
  if (functionalTemplate) {
    options.functional = true;
  }
  if (scopeId) {
    options._scopeId = "data-v-" + scopeId;
  }
  var hook;
  if (moduleIdentifier) {
    hook = function hook2(context) {
      context = context || // cached call
      this.$vnode && this.$vnode.ssrContext || // stateful
      this.parent && this.parent.$vnode && this.parent.$vnode.ssrContext;
      if (!context && typeof __VUE_SSR_CONTEXT__ !== "undefined") {
        context = __VUE_SSR_CONTEXT__;
      }
      if (injectStyles) {
        injectStyles.call(this, context);
      }
      if (context && context._registeredComponents) {
        context._registeredComponents.add(moduleIdentifier);
      }
    };
    options._ssrRegister = hook;
  } else if (injectStyles) {
    hook = shadowMode ? function() {
      injectStyles.call(this, (options.functional ? this.parent : this).$root.$options.shadowRoot);
    } : injectStyles;
  }
  if (hook) {
    if (options.functional) {
      options._injectStyles = hook;
      var originalRender = options.render;
      options.render = function renderWithStyleInjection(h, context) {
        hook.call(context);
        return originalRender(h, context);
      };
    } else {
      var existing = options.beforeCreate;
      options.beforeCreate = existing ? [].concat(existing, hook) : [hook];
    }
  }
  return {
    exports: scriptExports,
    options
  };
}

var __vue2_script = defineComponent({
  components: {
    TinyUserHead: UserHead
  },
  emits: ["click", "mouseenter"],
  props: [].concat(props, ["groupSize", "list", "horizontal", "showMax", "color", "backgroundColor"]),
  setup: function setup(props2, context) {
    return _setup({
      props: props2,
      context,
      renderless,
      api
    });
  }
});
var render = function render2() {
  var _vm = this;
  var _h = _vm.$createElement;
  var _c = _vm._self._c || _h;
  return _c("div", {
    staticClass: "inline-block",
    attrs: {
      "data-tag": "tiny-user-head-group"
    }
  }, [!_vm.horizontal ? _c("div", {
    class: [_vm.state.list.length === 3 ? "block text-center" : "flex items-center justify-around flex-wrap"],
    style: {
      "width": _vm.state.width + "px",
      "min-height": _vm.state.minHeight + "px"
    },
    attrs: {
      "data-tag": "tiny-user-head-group-horizontal"
    }
  }, [_vm.state.list.length === 3 ? [_c("div", {
    staticClass: "leading-[0] mb-px",
    attrs: {
      "data-tag": "tiny-user-head-group-first"
    }
  }, [_c("tiny-user-head", {
    attrs: {
      "background-color": _vm.state.list[0].backgroundColor,
      "color": _vm.state.list[0].color,
      "round": _vm.state.list[0].round,
      "type": _vm.state.list[0].type
    },
    model: {
      value: _vm.state.list[0].modelValue,
      callback: function callback($$v) {
        _vm.$set(_vm.state.list[0], "modelValue", $$v);
      },
      expression: "state.list[0].modelValue"
    }
  })], 1), _c("div", {
    staticClass: "flex items-center justify-around",
    attrs: {
      "data-tag": "tiny-user-head-group-center"
    }
  }, _vm._l(_vm.state.list.slice(1, 3), function(item, i) {
    return _c("div", {
      key: i,
      staticClass: "inline-block leading-[0]"
    }, [_c("tiny-user-head", {
      attrs: {
        "background-color": item.backgroundColor,
        "color": item.color,
        "round": item.round,
        "type": item.type
      },
      model: {
        value: item.modelValue,
        callback: function callback($$v) {
          _vm.$set(item, "modelValue", $$v);
        },
        expression: "item.modelValue"
      }
    })], 1);
  }), 0)] : _vm._l(_vm.state.list.slice(0, 4), function(item, i) {
    return _c("div", {
      key: i,
      staticClass: "leading-[0]",
      attrs: {
        "data-tag": "tiny-user-head-group-all"
      }
    }, [_c("tiny-user-head", {
      attrs: {
        "background-color": item.backgroundColor,
        "color": item.color,
        "round": item.round,
        "type": item.type
      },
      model: {
        value: item.modelValue,
        callback: function callback($$v) {
          _vm.$set(item, "modelValue", $$v);
        },
        expression: "item.modelValue"
      }
    })], 1);
  })], 2) : _c("div", {
    staticClass: "flex items-center cursor-pointer",
    attrs: {
      "data-tag": "tiny-user-head-group-nothorizontal"
    }
  }, [_vm._l(_vm.state.list.slice(0, _vm.state.list.length > 4 ? _vm.showMax ? _vm.state.list.length > 6 ? 5 : _vm.state.list.length : 3 : _vm.state.list.length), function(item, index) {
    return _c("div", {
      key: index,
      staticClass: "leading-[0]",
      style: {
        "margin-left": index !== 0 && -_vm.state.horizontalLeft + "px"
      },
      attrs: {
        "data-tag": "tiny-user-head-group-maxitem"
      }
    }, [_c("tiny-user-head", {
      staticClass: "rounded-full border border-color-bg-1 border-solid",
      attrs: {
        "round": item.round,
        "type": item.type
      },
      on: {
        "click": _vm.handleClick,
        "mouseenter": _vm.mouseEnter
      },
      model: {
        value: item.modelValue,
        callback: function callback($$v) {
          _vm.$set(item, "modelValue", $$v);
        },
        expression: "item.modelValue"
      }
    })], 1);
  }), _c("div", {
    class: ["leading-[0] z-10", _vm.state.list.length > 4 ? _vm.showMax ? _vm.state.list.length <= 6 && "hidden" : "block" : "hidden"],
    style: {
      "margin-left": -_vm.state.horizontalLeft + "px"
    },
    attrs: {
      "data-tag": "tiny-user-head-group-maxitem"
    }
  }, [_c("div", {
    staticClass: "rounded-full border border-color-bg-1 border-solid flex justify-center items-center text-color-text-primary bg-color-border-separator box-content",
    style: {
      "height": _vm.groupSize + "px",
      "width": _vm.groupSize + "px",
      "lineHeight": _vm.groupSize + "px"
    },
    attrs: {
      "data-tag": "tiny-user-head-group-size",
      "round": _vm.state.list[_vm.state.list.length - 1].round,
      "type": _vm.state.list[_vm.state.list.length - 1].type
    },
    on: {
      "click": _vm.handleClick,
      "mouseenter": _vm.mouseEnter
    }
  }, [_vm._v(" " + _vm._s("+" + (_vm.state.list.length - (_vm.showMax ? 6 : 3))) + " ")])])], 2)]);
};
var staticRenderFns = [];
var __cssModules = {};
var __component__ = /* @__PURE__ */ normalizeComponent(__vue2_script, render, staticRenderFns, false, __vue2_injectStyles, null, null, null);
function __vue2_injectStyles(context) {
  for (var o in __cssModules) {
    this[o] = __cssModules[o];
  }
}
var mobileFirst = /* @__PURE__ */ function() {
  return __component__.exports;
}();
export {
  mobileFirst as default
};

==> vue-user-head-group-2.22.1.tgz: package/lib/mobile-first.js <==
import { renderless, api } from '@opentinyvue/vue-renderless/user-head-group/vue';
import { defineComponent, props, setup } from '@opentinyvue/vue-common';
import UserHead from '@opentinyvue/vue-user-head';

function normalizeComponent(scriptExports, render, staticRenderFns, functionalTemplate, injectStyles, scopeId, moduleIdentifier, shadowMode) {
  var options = typeof scriptExports === "function" ? scriptExports.options : scriptExports;
  if (render) {
    options.render = render;
    options.staticRenderFns = staticRenderFns;
    options._compiled = true;
  }
  var hook;
  if (injectStyles) {
    hook = injectStyles;
  }
  if (hook) {
    if (options.functional) {
      options._injectStyles = hook;
      var originalRender = options.render;
      options.render = function renderWithStyleInjection(h, context) {
        hook.call(context);
        return originalRender(h, context);
      };
    } else {
      var existing = options.beforeCreate;
      options.beforeCreate = existing ? [].concat(existing, hook) : [hook];
    }
  }
  return {
    exports: scriptExports,
    options
  };
}

var __vue2_script = defineComponent({
  components: {
    TinyUserHead: UserHead
  },
  emits: ["click", "mouseenter"],
  props: [].concat(props, ["groupSize", "list", "horizontal", "showMax", "color", "backgroundColor"]),
  setup: function setup$1(props2, context) {
    return setup({
      props: props2,
      context,
      renderless,
      api
    });
  }
});
var render = function render2() {
  var _vm = this;
  var _h = _vm.$createElement;
  var _c = _vm._self._c || _h;
  return _c("div", {
    staticClass: "inline-block",
    attrs: {
      "data-tag": "tiny-user-head-group"
    }
  }, [!_vm.horizontal ? _c("div", {
    class: [_vm.state.list.length === 3 ? "block text-center" : "flex items-center justify-around flex-wrap"],
    style: {
      "width": _vm.state.width + "px",
      "min-height": _vm.state.minHeight + "px"
    },
    attrs: {
      "data-tag": "tiny-user-head-group-horizontal"
    }
  }, [_vm.state.list.length === 3 ? [_c("div", {
    staticClass: "leading-[0] mb-px",
    attrs: {
      "data-tag": "tiny-user-head-group-first"
    }
  }, [_c("tiny-user-head", {
    attrs: {
      "background-color": _vm.state.list[0].backgroundColor,
      "color": _vm.state.list[0].color,
      "round": _vm.state.list[0].round,
      "type": _vm.state.list[0].type
    },
    model: {
      value: _vm.state.list[0].modelValue,
      callback: function callback($$v) {
        _vm.$set(_vm.state.list[0], "modelValue", $$v);
      },
      expression: "state.list[0].modelValue"
    }
  })], 1), _c("div", {
    staticClass: "flex items-center justify-around",
    attrs: {
      "data-tag": "tiny-user-head-group-center"
    }
  }, _vm._l(_vm.state.list.slice(1, 3), function(item, i) {
    return _c("div", {
      key: i,
      staticClass: "inline-block leading-[0]"
    }, [_c("tiny-user-head", {
      attrs: {
        "background-color": item.backgroundColor,
        "color": item.color,
        "round": item.round,
        "type": item.type
      },
      model: {
        value: item.modelValue,
        callback: function callback($$v) {
          _vm.$set(item, "modelValue", $$v);
        },
        expression: "item.modelValue"
      }
    })], 1);
  }), 0)] : _vm._l(_vm.state.list.slice(0, 4), function(item, i) {
    return _c("div", {
      key: i,
      staticClass: "leading-[0]",
      attrs: {
        "data-tag": "tiny-user-head-group-all"
      }
    }, [_c("tiny-user-head", {
      attrs: {
        "background-color": item.backgroundColor,
        "color": item.color,
        "round": item.round,
        "type": item.type
      },
      model: {
        value: item.modelValue,
        callback: function callback($$v) {
          _vm.$set(item, "modelValue", $$v);
        },
        expression: "item.modelValue"
      }
    })], 1);
  })], 2) : _c("div", {
    staticClass: "flex items-center cursor-pointer",
    attrs: {
      "data-tag": "tiny-user-head-group-nothorizontal"
    }
  }, [_vm._l(_vm.state.list.slice(0, _vm.state.list.length > 4 ? _vm.showMax ? _vm.state.list.length > 6 ? 5 : _vm.state.list.length : 3 : _vm.state.list.length), function(item, index) {
    return _c("div", {
      key: index,
      staticClass: "leading-[0]",
      style: {
        "margin-left": index !== 0 && -_vm.state.horizontalLeft + "px"
      },
      attrs: {
        "data-tag": "tiny-user-head-group-maxitem"
      }
    }, [_c("tiny-user-head", {
      staticClass: "rounded-full border border-color-bg-1 border-solid",
      attrs: {
        "round": item.round,
        "type": item.type
      },
      on: {
        "click": _vm.handleClick,
        "mouseenter": _vm.mouseEnter
      },
      model: {
        value: item.modelValue,
        callback: function callback($$v) {
          _vm.$set(item, "modelValue", $$v);
        },
        expression: "item.modelValue"
      }
    })], 1);
  }), _c("div", {
    class: ["leading-[0] z-10", _vm.state.list.length > 4 ? _vm.showMax ? _vm.state.list.length <= 6 && "hidden" : "block" : "hidden"],
    style: {
      "margin-left": -_vm.state.horizontalLeft + "px"
    },
    attrs: {
      "data-tag": "tiny-user-head-group-maxitem"
    }
  }, [_c("div", {
    staticClass: "rounded-full border border-color-bg-1 border-solid flex justify-center items-center text-color-text-primary bg-color-border-separator box-content",
    style: {
      "height": _vm.groupSize + "px",
      "width": _vm.groupSize + "px",
      "lineHeight": _vm.groupSize + "px"
    },
    attrs: {
      "data-tag": "tiny-user-head-group-size",
      "round": _vm.state.list[_vm.state.list.length - 1].round,
      "type": _vm.state.list[_vm.state.list.length - 1].type
    },
    on: {
      "click": _vm.handleClick,
      "mouseenter": _vm.mouseEnter
    }
  }, [_vm._v(" " + _vm._s("+" + (_vm.state.list.length - (_vm.showMax ? 6 : 3))) + " ")])])], 2)]);
};
var staticRenderFns = [];
var __cssModules = {};
var __component__ = /* @__PURE__ */ normalizeComponent(__vue2_script, render, staticRenderFns, false, __vue2_injectStyles);
function __vue2_injectStyles(context) {
  for (var o in __cssModules) {
    this[o] = __cssModules[o];
  }
}
var mobileFirst = /* @__PURE__ */ function() {
  return __component__.exports;
}();

export { mobileFirst as default };
